==> haskell-keys-3.12.4-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-keys.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 keys
version:              3.12.4
visibility:           public
id:                   keys-3.12.4-1iwmktwOtPB2d9G0YBfDFq
key:                  keys-3.12.4-1iwmktwOtPB2d9G0YBfDFq
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/keys/
synopsis:             Keyed functors and containers
description:
    This package provides a bunch of ad hoc classes for accessing parts of a container.

    In practice this package is largely subsumed by the
    <https://hackage.haskell.org/package/lens lens package>,
    but it is maintained for now as it has much
    simpler dependencies.

category:             Data Structures, Containers
abi:                  0e5a612d77d2edd85d767b67136d0a7a
exposed:              True
exposed-modules:      Data.Key
import-dirs:          /usr/lib/ghc-9.4.8/site-local/keys-3.12.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/keys-3.12.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/keys-3.12.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-keys
hs-libraries:         HSkeys-3.12.4-1iwmktwOtPB2d9G0YBfDFq
depends:
    array-0.5.4.0 base-4.17.2.1 comonad-5.0.9-WdRIGdTjRI2TeSrvZ2o2
    containers-0.6.7 free-5.2-8DggMDoUY4K6zjiX7Mezzv
    hashable-1.4.4.0-Bi9h4Si3Ui62sqHmMmGfiv
    semigroupoids-6.0.1-ArTD9Cr9btFACC9w7rlHRP
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-3czZ5Len2GTFaAkRxFZe7E

haddock-interfaces:   /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html:         /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-keys-3.12.4-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-keys.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 keys
version:              3.12.4
visibility:           public
id:                   keys-3.12.4-46cK4tChi6J2DnBsvK8Cmf
key:                  keys-3.12.4-46cK4tChi6J2DnBsvK8Cmf
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/keys/
synopsis:             Keyed functors and containers
description:
    This package provides a bunch of ad hoc classes for accessing parts of a container.

    In practice this package is largely subsumed by the
    <https://hackage.haskell.org/package/lens lens package>,
    but it is maintained for now as it has much
    simpler dependencies.

category:             Data Structures, Containers
abi:                  e7abe2c3cf64c4370a9cbe60ce8d24dc
exposed:              True
exposed-modules:      Data.Key
import-dirs:          /usr/lib/ghc-9.4.8/site-local/keys-3.12.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/keys-3.12.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/keys-3.12.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-keys
hs-libraries:         HSkeys-3.12.4-46cK4tChi6J2DnBsvK8Cmf
depends:
    array-0.5.4.0 base-4.17.2.1 comonad-5.0.9-I2bM6t8c2fB7rHIs9XjGyy
    containers-0.6.7 free-5.2-2DfaNEYCqFiJ01zSxrx2uR
    hashable-1.4.4.0-85lkkmOSRZHDIzkr9EkKNp
    semigroupoids-6.0.1-HojjKCFNEldAzPbwF6sStW
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-Cw2Ec4BgC4sInKE4e5RLSk

haddock-interfaces:   /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html:         /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
